XML Résumé Library User Guide

# XMLRésuméLibrary: User Guide

|  | Introduction

# XML Résumé Library User Guide

## For XML Résumé Library Version 1.5.1

### Bruce Christensen

Copyright © 2002 Bruce Christensen, Peter Hutnick, Mark Miller

Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.1 or any later version published by the Free Software Foundation; with no invariant sections, with no Front-Cover Texts, and with no Back-Cover Texts. A copy of the license is included in the section entitled “GNU Free Documentation License”.

27 November 2002

|  | Introduction